/*
 * Copyright (C) 2015 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SUBSCRIPTIONSOURCETYPEMODEL_H
#define SUBSCRIPTIONSOURCETYPEMODEL_H

#include "selectionmodel.h"
#include "subscription.h"
#include "subscriptionplugins.h"

class SubscriptionSourceTypeModel : public SelectionModel
{
    Q_OBJECT
    
public:
    explicit SubscriptionSourceTypeModel(QObject *parent = 0) :
        SelectionModel(parent)
    {
        append(tr("URL"), Subscription::Url);
        append(tr("Local file"), Subscription::LocalFile);
        append(tr("Command"), Subscription::Command);
        
        foreach (QString name, SubscriptionPlugins::pluginNames()) {
            append(name, Subscription::Plugin);
        }
    }
};

#endif // SUBSCRIPTIONSOURCETYPEMODEL_H
